@@ -1,6 +1,6 @@
 package Math::PariBuild;
 
-$VERSION = '2.030524';
+$VERSION = '2.030525';
 
 require Exporter;
 @ISA = 'Exporter';
@@ -426,7 +426,7 @@ EOP
 	my ($eA, $eM, $eC, $eE, $tI, $tO, $tE, $pO, $pE)
 	  = (@ENV{ qw(AUTOMATED_TESTING PERL_MM_USE_DEFAULT PERL5_CPAN_IS_RUNNING PERL_EXTUTILS_AUTOINSTALL) },
 	     -t STDIN, -t STDOUT, -t STDERR, -p STDERR, -p STDOUT);
-	defined() ? $_ = "'$_'" : $_ = '<undef>' for $eA, $eM, $eC, $eE;
+	defined() ? $_ = "'$_'" : ($_ = '<undef>') for $eA, $eM, $eC, $eE;
 	my @ans = map {sprintf '%#x', ord} split //, $ans;
         print <<EOP;	# Is AUTOMATED_TESTING ALWAYS defined on smoke???
 
